# encoding=utf-8

import time
import functools

__all__ = ['timer']


def timer(func):
	"""
	装饰器函数，用于计算func运行耗时，并将运行时间输出至屏幕上，结果保留小数点后3位

	类似的有timeit等
	:param func:
	:return:
	"""

	@functools.wraps(func)
	def _wrapper(*args, **kwargs):
		start = time.time()
		r = func(*args, **kwargs)
		end = time.time()
		cost = end - start
		print '耗时：%0.3f s' % cost
		return r

	return _wrapper



# encoding=utf-8

from setuptools import setup, find_packages

setup(
	name='yekit',
	version='0.1.2',
	description='a useful toolkit',
	classifiers=[
		'License :: OSI Approved :: BSD License',
		'Programming Language :: Python :: 2.7',
		'Intended Audience :: Developers',
		'Operating System :: OS Independent',
	],
	keywords='tool kit',
	author='ye',
	url='http://www.xuye.site',
	author_email='wmxy123@yeah.net',
	license='BSD',
	packages=find_packages(exclude=['']),  # 需要处理哪里packages，当然也可以手动填，例如['pip_setup', 'pip_setup.ext']
	include_package_data=False,
	zip_safe=True,
	install_requires=[],
)
